/* Automatically @generated by tree-sitter v0.25.10 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 44
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 42
#define ALIAS_COUNT 0
#define TOKEN_COUNT 28
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 10
#define MAX_ALIAS_SEQUENCE_LENGTH 4
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 6
#define SUPERTYPE_COUNT 1

enum ts_symbol_identifiers {
  anon_sym_DOLLAR_LBRACE_LBRACE = 1,
  anon_sym_RBRACE_RBRACE = 2,
  anon_sym_LPAREN = 3,
  anon_sym_RPAREN = 4,
  anon_sym_STAR = 5,
  anon_sym_DOT = 6,
  anon_sym_LBRACK = 7,
  anon_sym_RBRACK = 8,
  anon_sym_BANG = 9,
  anon_sym_GT = 10,
  anon_sym_LT = 11,
  anon_sym_GT_EQ = 12,
  anon_sym_LT_EQ = 13,
  anon_sym_EQ_EQ = 14,
  anon_sym_BANG_EQ = 15,
  anon_sym_AMP_AMP = 16,
  anon_sym_PIPE_PIPE = 17,
  anon_sym_COMMA = 18,
  sym_identifier = 19,
  sym_number = 20,
  anon_sym_SQUOTE = 21,
  sym_string_fragment = 22,
  sym_escape = 23,
  sym_true = 24,
  sym_false = 25,
  sym_null = 26,
  sym_text = 27,
  sym_source = 28,
  sym__actions_expression = 29,
  sym__expression = 30,
  sym_parenthesized_expression = 31,
  sym_dereference_expression = 32,
  sym_subscript_expression = 33,
  sym_unary_expression = 34,
  sym_binary_expression = 35,
  sym_function_call = 36,
  sym_argument_list = 37,
  sym_string = 38,
  aux_sym_source_repeat1 = 39,
  aux_sym_argument_list_repeat1 = 40,
  aux_sym_string_repeat1 = 41,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_DOLLAR_LBRACE_LBRACE] = "${{",
  [anon_sym_RBRACE_RBRACE] = "}}",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_STAR] = "*",
  [anon_sym_DOT] = ".",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_BANG] = "!",
  [anon_sym_GT] = ">",
  [anon_sym_LT] = "<",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_COMMA] = ",",
  [sym_identifier] = "identifier",
  [sym_number] = "number",
  [anon_sym_SQUOTE] = "'",
  [sym_string_fragment] = "string_fragment",
  [sym_escape] = "escape",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_null] = "null",
  [sym_text] = "text",
  [sym_source] = "source",
  [sym__actions_expression] = "_actions_expression",
  [sym__expression] = "_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_dereference_expression] = "dereference_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_function_call] = "function_call",
  [sym_argument_list] = "argument_list",
  [sym_string] = "string",
  [aux_sym_source_repeat1] = "source_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_DOLLAR_LBRACE_LBRACE] = anon_sym_DOLLAR_LBRACE_LBRACE,
  [anon_sym_RBRACE_RBRACE] = anon_sym_RBRACE_RBRACE,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [sym_identifier] = sym_identifier,
  [sym_number] = sym_number,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [sym_string_fragment] = sym_string_fragment,
  [sym_escape] = sym_escape,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_null] = sym_null,
  [sym_text] = sym_text,
  [sym_source] = sym_source,
  [sym__actions_expression] = sym__actions_expression,
  [sym__expression] = sym__expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_dereference_expression] = sym_dereference_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_function_call] = sym_function_call,
  [sym_argument_list] = sym_argument_list,
  [sym_string] = sym_string,
  [aux_sym_source_repeat1] = aux_sym_source_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_DOLLAR_LBRACE_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_string_fragment] = {
    .visible = true,
    .named = true,
  },
  [sym_escape] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [sym_text] = {
    .visible = true,
    .named = true,
  },
  [sym_source] = {
    .visible = true,
    .named = true,
  },
  [sym__actions_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_dereference_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_argument = 1,
  field_arguments = 2,
  field_index = 3,
  field_left = 4,
  field_name = 5,
  field_object = 6,
  field_operand = 7,
  field_operator = 8,
  field_property = 9,
  field_right = 10,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_index] = "index",
  [field_left] = "left",
  [field_name] = "name",
  [field_object] = "object",
  [field_operand] = "operand",
  [field_operator] = "operator",
  [field_property] = "property",
  [field_right] = "right",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 2},
  [2] = {.index = 2, .length = 2},
  [3] = {.index = 4, .length = 2},
  [4] = {.index = 6, .length = 3},
  [5] = {.index = 9, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_operand, 1},
    {field_operator, 0},
  [2] =
    {field_arguments, 1},
    {field_name, 0},
  [4] =
    {field_object, 0},
    {field_property, 2},
  [6] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [9] =
    {field_argument, 0},
    {field_index, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
};

static const TSSymbol ts_supertype_symbols[SUPERTYPE_COUNT] = {
  sym__expression,
};

static const TSMapSlice ts_supertype_map_slices[] = {
  [sym__expression] = {.index = 0, .length = 12},
};

static const TSSymbol ts_supertype_map_entries[] = {
  [0] =
    sym_binary_expression,
    sym_dereference_expression,
    sym_false,
    sym_function_call,
    sym_identifier,
    sym_null,
    sym_number,
    sym_parenthesized_expression,
    sym_string,
    sym_subscript_expression,
    sym_true,
    sym_unary_expression,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(26);
      ADVANCE_MAP(
        '!', 37,
        '$', 11,
        '&', 3,
        '\'', 69,
        '(', 29,
        ')', 30,
        '*', 31,
        ',', 46,
        '.', 33,
        '0', 59,
        '<', 39,
        '=', 7,
        '>', 38,
        '[', 34,
        ']', 35,
        'f', 47,
        'n', 56,
        't', 53,
        '|', 13,
        '}', 14,
        '+', 5,
        '-', 5,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(25);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(60);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '!', 36,
        '\'', 68,
        '(', 29,
        ')', 30,
        '*', 31,
        '.', 19,
        '0', 59,
        'f', 47,
        'n', 56,
        't', 53,
        '+', 5,
        '-', 5,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(60);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 6,
        '&', 3,
        '(', 29,
        ')', 30,
        '*', 31,
        ',', 46,
        '.', 32,
        '<', 39,
        '=', 7,
        '>', 38,
        '[', 34,
        ']', 35,
        '|', 13,
        '}', 14,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 3:
      if (lookahead == '&') ADVANCE(44);
      END_STATE();
    case 4:
      if (lookahead == '\'') ADVANCE(69);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(70);
      if (lookahead != 0) ADVANCE(71);
      END_STATE();
    case 5:
      if (lookahead == '.') ADVANCE(19);
      if (lookahead == '0') ADVANCE(59);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(60);
      END_STATE();
    case 6:
      if (lookahead == '=') ADVANCE(43);
      END_STATE();
    case 7:
      if (lookahead == '=') ADVANCE(42);
      END_STATE();
    case 8:
      if (lookahead == '{') ADVANCE(27);
      END_STATE();
    case 9:
      if (lookahead == '{') ADVANCE(27);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(77);
      END_STATE();
    case 10:
      if (lookahead == '{') ADVANCE(23);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(77);
      END_STATE();
    case 11:
      if (lookahead == '{') ADVANCE(8);
      END_STATE();
    case 12:
      if (lookahead == '{') ADVANCE(9);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(77);
      END_STATE();
    case 13:
      if (lookahead == '|') ADVANCE(45);
      END_STATE();
    case 14:
      if (lookahead == '}') ADVANCE(28);
      END_STATE();
    case 15:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(21);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 16:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(62);
      END_STATE();
    case 17:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(63);
      END_STATE();
    case 18:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(60);
      END_STATE();
    case 19:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 20:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      END_STATE();
    case 21:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 22:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(64);
      END_STATE();
    case 23:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '{') ADVANCE(77);
      END_STATE();
    case 24:
      if (eof) ADVANCE(26);
      if (lookahead == '\n') SKIP(24);
      if (lookahead == '$') ADVANCE(12);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(76);
      if (lookahead != 0) ADVANCE(77);
      END_STATE();
    case 25:
      if (eof) ADVANCE(26);
      ADVANCE_MAP(
        '!', 37,
        '$', 11,
        '&', 3,
        '\'', 68,
        '(', 29,
        ')', 30,
        '*', 31,
        ',', 46,
        '.', 33,
        '0', 59,
        '<', 39,
        '=', 7,
        '>', 38,
        '[', 34,
        ']', 35,
        'f', 47,
        'n', 56,
        't', 53,
        '|', 13,
        '}', 14,
        '+', 5,
        '-', 5,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(25);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(60);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_DOLLAR_LBRACE_LBRACE);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_RBRACE_RBRACE);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(43);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(40);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(41);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(50);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(73);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(74);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(54);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(75);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(51);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(55);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(49);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(48);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(52);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(sym_number);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(sym_number);
      ADVANCE_MAP(
        '.', 67,
        '0', 61,
        '_', 20,
        'n', 58,
        'B', 16,
        'b', 16,
        'E', 15,
        'e', 15,
        'O', 17,
        'o', 17,
        'X', 22,
        'x', 22,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(60);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(67);
      if (lookahead == '_') ADVANCE(18);
      if (lookahead == 'n') ADVANCE(58);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(60);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(20);
      if (lookahead == 'n') ADVANCE(58);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(61);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(16);
      if (lookahead == 'n') ADVANCE(58);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(62);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(17);
      if (lookahead == 'n') ADVANCE(58);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(63);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(22);
      if (lookahead == 'n') ADVANCE(58);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(64);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(19);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '_') ADVANCE(21);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '\'') ADVANCE(72);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(sym_string_fragment);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(70);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(71);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_string_fragment);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(71);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(sym_escape);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(sym_true);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(sym_false);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(sym_null);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(sym_text);
      if (lookahead == '$') ADVANCE(12);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(76);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(77);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(sym_text);
      if (lookahead == '$') ADVANCE(10);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(77);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 24},
  [2] = {.lex_state = 1},
  [3] = {.lex_state = 1},
  [4] = {.lex_state = 1},
  [5] = {.lex_state = 1},
  [6] = {.lex_state = 1},
  [7] = {.lex_state = 1},
  [8] = {.lex_state = 1},
  [9] = {.lex_state = 1},
  [10] = {.lex_state = 1},
  [11] = {.lex_state = 1},
  [12] = {.lex_state = 2},
  [13] = {.lex_state = 2},
  [14] = {.lex_state = 2},
  [15] = {.lex_state = 2},
  [16] = {.lex_state = 2},
  [17] = {.lex_state = 2},
  [18] = {.lex_state = 2},
  [19] = {.lex_state = 2},
  [20] = {.lex_state = 2},
  [21] = {.lex_state = 2},
  [22] = {.lex_state = 2},
  [23] = {.lex_state = 2},
  [24] = {.lex_state = 2},
  [25] = {.lex_state = 2},
  [26] = {.lex_state = 2},
  [27] = {.lex_state = 2},
  [28] = {.lex_state = 2},
  [29] = {.lex_state = 2},
  [30] = {.lex_state = 2},
  [31] = {.lex_state = 2},
  [32] = {.lex_state = 2},
  [33] = {.lex_state = 24},
  [34] = {.lex_state = 24},
  [35] = {.lex_state = 4},
  [36] = {.lex_state = 4},
  [37] = {.lex_state = 4},
  [38] = {.lex_state = 24},
  [39] = {.lex_state = 0},
  [40] = {.lex_state = 0},
  [41] = {.lex_state = 2},
  [42] = {.lex_state = 2},
  [43] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_DOLLAR_LBRACE_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE_RBRACE] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym_escape] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_null] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source] = STATE(43),
    [sym__actions_expression] = STATE(33),
    [aux_sym_source_repeat1] = STATE(33),
    [ts_builtin_sym_end] = ACTIONS(3),
    [anon_sym_DOLLAR_LBRACE_LBRACE] = ACTIONS(5),
    [sym_text] = ACTIONS(7),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 10,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(11), 1,
      anon_sym_RPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(28), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [39] = 9,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(30), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [75] = 9,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(15), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [111] = 9,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(32), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [147] = 9,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(31), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [183] = 9,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(21), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [219] = 9,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(25), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [255] = 9,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(13), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [291] = 9,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(23), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [327] = 9,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_STAR,
    ACTIONS(15), 1,
      anon_sym_BANG,
    ACTIONS(17), 1,
      sym_identifier,
    ACTIONS(19), 1,
      sym_number,
    ACTIONS(21), 1,
      anon_sym_SQUOTE,
    STATE(29), 1,
      sym__expression,
    ACTIONS(23), 3,
      sym_true,
      sym_false,
      sym_null,
    STATE(16), 7,
      sym_parenthesized_expression,
      sym_dereference_expression,
      sym_subscript_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_function_call,
      sym_string,
  [363] = 4,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    STATE(17), 1,
      sym_argument_list,
    ACTIONS(29), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(25), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [388] = 6,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(37), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(39), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(41), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(31), 6,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [415] = 2,
    ACTIONS(45), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(43), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [434] = 4,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(49), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(47), 10,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [457] = 2,
    ACTIONS(29), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(25), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [476] = 2,
    ACTIONS(53), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(51), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [495] = 2,
    ACTIONS(57), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(55), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [514] = 2,
    ACTIONS(61), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(59), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [533] = 2,
    ACTIONS(65), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(63), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [552] = 4,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(67), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(31), 10,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [575] = 2,
    ACTIONS(71), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(69), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [594] = 7,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_AMP_AMP,
    ACTIONS(37), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(39), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(41), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(31), 5,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [623] = 2,
    ACTIONS(77), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(75), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [642] = 5,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(37), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(39), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(31), 8,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [667] = 2,
    ACTIONS(81), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(79), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [686] = 2,
    ACTIONS(85), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(83), 12,
      anon_sym_RBRACE_RBRACE,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
  [705] = 10,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_AMP_AMP,
    ACTIONS(87), 1,
      anon_sym_RPAREN,
    ACTIONS(89), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(91), 1,
      anon_sym_COMMA,
    STATE(39), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(37), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(39), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(41), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [739] = 8,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_AMP_AMP,
    ACTIONS(89), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(37), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(39), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(41), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(93), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [768] = 8,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_AMP_AMP,
    ACTIONS(89), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(95), 1,
      anon_sym_RBRACE_RBRACE,
    ACTIONS(37), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(39), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(41), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [796] = 8,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_AMP_AMP,
    ACTIONS(89), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(97), 1,
      anon_sym_RBRACK,
    ACTIONS(37), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(39), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(41), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [824] = 8,
    ACTIONS(33), 1,
      anon_sym_DOT,
    ACTIONS(35), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_AMP_AMP,
    ACTIONS(89), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(99), 1,
      anon_sym_RPAREN,
    ACTIONS(37), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(39), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(41), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [852] = 4,
    ACTIONS(5), 1,
      anon_sym_DOLLAR_LBRACE_LBRACE,
    ACTIONS(101), 1,
      ts_builtin_sym_end,
    ACTIONS(103), 1,
      sym_text,
    STATE(34), 2,
      sym__actions_expression,
      aux_sym_source_repeat1,
  [866] = 4,
    ACTIONS(105), 1,
      ts_builtin_sym_end,
    ACTIONS(107), 1,
      anon_sym_DOLLAR_LBRACE_LBRACE,
    ACTIONS(110), 1,
      sym_text,
    STATE(34), 2,
      sym__actions_expression,
      aux_sym_source_repeat1,
  [880] = 3,
    ACTIONS(113), 1,
      anon_sym_SQUOTE,
    STATE(37), 1,
      aux_sym_string_repeat1,
    ACTIONS(115), 2,
      sym_string_fragment,
      sym_escape,
  [891] = 3,
    ACTIONS(117), 1,
      anon_sym_SQUOTE,
    STATE(35), 1,
      aux_sym_string_repeat1,
    ACTIONS(119), 2,
      sym_string_fragment,
      sym_escape,
  [902] = 3,
    ACTIONS(121), 1,
      anon_sym_SQUOTE,
    STATE(37), 1,
      aux_sym_string_repeat1,
    ACTIONS(123), 2,
      sym_string_fragment,
      sym_escape,
  [913] = 2,
    ACTIONS(128), 1,
      anon_sym_DOLLAR_LBRACE_LBRACE,
    ACTIONS(126), 2,
      ts_builtin_sym_end,
      sym_text,
  [921] = 3,
    ACTIONS(91), 1,
      anon_sym_COMMA,
    ACTIONS(130), 1,
      anon_sym_RPAREN,
    STATE(40), 1,
      aux_sym_argument_list_repeat1,
  [931] = 3,
    ACTIONS(93), 1,
      anon_sym_RPAREN,
    ACTIONS(132), 1,
      anon_sym_COMMA,
    STATE(40), 1,
      aux_sym_argument_list_repeat1,
  [941] = 1,
    ACTIONS(135), 2,
      anon_sym_STAR,
      sym_identifier,
  [946] = 1,
    ACTIONS(33), 1,
      anon_sym_DOT,
  [950] = 1,
    ACTIONS(137), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 39,
  [SMALL_STATE(4)] = 75,
  [SMALL_STATE(5)] = 111,
  [SMALL_STATE(6)] = 147,
  [SMALL_STATE(7)] = 183,
  [SMALL_STATE(8)] = 219,
  [SMALL_STATE(9)] = 255,
  [SMALL_STATE(10)] = 291,
  [SMALL_STATE(11)] = 327,
  [SMALL_STATE(12)] = 363,
  [SMALL_STATE(13)] = 388,
  [SMALL_STATE(14)] = 415,
  [SMALL_STATE(15)] = 434,
  [SMALL_STATE(16)] = 457,
  [SMALL_STATE(17)] = 476,
  [SMALL_STATE(18)] = 495,
  [SMALL_STATE(19)] = 514,
  [SMALL_STATE(20)] = 533,
  [SMALL_STATE(21)] = 552,
  [SMALL_STATE(22)] = 575,
  [SMALL_STATE(23)] = 594,
  [SMALL_STATE(24)] = 623,
  [SMALL_STATE(25)] = 642,
  [SMALL_STATE(26)] = 667,
  [SMALL_STATE(27)] = 686,
  [SMALL_STATE(28)] = 705,
  [SMALL_STATE(29)] = 739,
  [SMALL_STATE(30)] = 768,
  [SMALL_STATE(31)] = 796,
  [SMALL_STATE(32)] = 824,
  [SMALL_STATE(33)] = 852,
  [SMALL_STATE(34)] = 866,
  [SMALL_STATE(35)] = 880,
  [SMALL_STATE(36)] = 891,
  [SMALL_STATE(37)] = 902,
  [SMALL_STATE(38)] = 913,
  [SMALL_STATE(39)] = 921,
  [SMALL_STATE(40)] = 931,
  [SMALL_STATE(41)] = 941,
  [SMALL_STATE(42)] = 946,
  [SMALL_STATE(43)] = 950,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source, 0, 0, 0),
  [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [25] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [29] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [31] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 4),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [43] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [45] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [47] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 1),
  [49] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 1),
  [51] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 2),
  [53] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 2),
  [55] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [57] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [59] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dereference_expression, 3, 0, 3),
  [61] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dereference_expression, 3, 0, 3),
  [63] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [65] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [67] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 4),
  [69] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [71] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [75] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [77] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [79] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 4, 0, 5),
  [81] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 4, 0, 5),
  [83] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [85] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [93] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source, 1, 0, 0),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_repeat1, 2, 0, 0),
  [107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_repeat1, 2, 0, 0), SHIFT_REPEAT(3),
  [110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_repeat1, 2, 0, 0), SHIFT_REPEAT(34),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [123] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(37),
  [126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__actions_expression, 3, 0, 0),
  [128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__actions_expression, 3, 0, 0),
  [130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [132] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(11),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [137] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_ghactions(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .supertype_map_slices = ts_supertype_map_slices,
    .supertype_map_entries = ts_supertype_map_entries,
    .supertype_symbols = ts_supertype_symbols,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "ghactions",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 2,
      .patch_version = 5,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
